/**
 * @license https://github.com/Intermesh/goui/blob/main/LICENSE MIT License
 * @copyright Copyright 2023 Intermesh BV
 * @author Merijn Schering <mschering@intermesh.nl>
 */
import { Field, FieldEventMap } from "./Field.js";
import { Component } from "../Component.js";
import { Config } from "../Observable";
/**
 * Display field
 *
 * Component used to display data only.
 *
 * A {@see Form} can be used to edit data but also to present data using display fields
 */
export declare class DisplayField extends Field {
    protected baseCls: string;
    /**
     * Renderer function for the value of the field
     *
     * @param v
     * @param field
     */
    renderer: DisplayFieldRenderer;
    /**
     * Hide this field when the value is empty
     */
    hideWhenEmpty: boolean;
    protected createControl(): HTMLElement | undefined;
    protected internalSetValue(v?: any): void;
}
type DisplayFieldRenderer = (v: any, field: DisplayField) => string | Promise<string>;
type DisplayFieldConfig = Config<DisplayField, FieldEventMap<DisplayField>> & {
    /**
     * Renderer function for the value of the field
     */
    renderer?: DisplayFieldRenderer;
};
/**
 * Shortcut function to create a {@see DisplayField}
 *
 * @param config
 * @param items
 */
export declare const displayfield: (config: DisplayFieldConfig, ...items: Component[]) => DisplayField;
/**
 * Create display field with date icon and renderer
 *
 * @param config
 * @param items
 */
export declare const displaydatefield: (config: DisplayFieldConfig, ...items: Component[]) => DisplayField;
export {};
//# sourceMappingURL=DisplayField.d.ts.map